@@ -270,14 +270,12 @@ class RestChannelAsyncClient:
         self._sleep_event = threading.Event()
         self._lock = threading.Lock()
 
-    def start(self) -> None:
-        """
-        Starts the asynchronous client, initiating the heartbeat thread.
-        """
+    def __enter__(self):
         self._thread.start()
         _logger.info('RestChannelAsyncClient started.')
+        return self
 
-    def close(self) -> None:
+    def __exit__(self, exc_type, exc_value, traceback):
         """
         Stops the asynchronous client and terminates the heartbeat thread.
         """
