@@ -2,6 +2,7 @@
 This module provides classes and utility functions for working with Humatron,
 including request and response handling, payload processing, and asynchronous execution.
 """
+import logging
 
 """
 " ██╗  ██╗██╗   ██╗███╗   ███╗ █████╗ ████████╗██████╗  ██████╗ ███╗   ██╗
@@ -181,6 +182,10 @@ class Response(NamedTuple):
         }
 
 
+logging.basicConfig(encoding='utf-8', level=logging.DEBUG)
+_logger = logging.getLogger('humatron.worker.sdk')
+
+
 class HumatronWorker(ABC):
     """
     Abstract base class for a Humatron worker.
@@ -267,7 +272,63 @@ class HumatronWorkerAsyncAdapter(HumatronWorker, ABC):
         @return:
             The response after processing the request, or None if no response is available.
         """
-        # Implementation omitted for brevity, can be extended as needed.
+        if req.req_cmd == 'interview':
+            if req.storage:
+                raise ValueError('Storage cannot be provided for `interview` requests.')
+            elif not req.payload or len(req.payload) != 1:
+                raise ValueError('Invalid payload for `interview` request.')
+
+            pp = self.execute(RequestPayloadPart(req.req_cmd, req.req_id, req.req_tstamp, req.payload[0]), None)
+
+            match pp:
+                case dict():
+                    return Response(make_id(), _utc_now_iso_format(), [pp], None)
+                case _:
+                    raise ValueError(f'Unexpected response payload for `interview` request [payload={pp}]')
+
+        if self._storage is None:
+            self._storage = LockedDict()
+            self._storage.update(req.storage)
+
+        def fn() -> None:
+            try:
+                res: list[PayloadPart] = []
+                if req.payload:
+                    for parts in req.payload:
+                        parts = self.execute(
+                            RequestPayloadPart(req.req_cmd, req.req_id, req.req_tstamp, parts), self._storage
+                        )
+
+                        if parts is not None:
+                            if not isinstance(parts, list):
+                                parts = [parts]
+
+                            parts = list(filter(lambda el: el, parts)) if parts else None
+
+                            if parts:
+                                res.extend(parts)
+                    with self._lock:
+                        if res:
+                            self._payloads_parts.extend(res)
+            except Exception as e:
+                _logger.error(f'Error during processing [error={e}]', exc_info=True)
+
+        self._pool.submit(fn)
+
+        with self._lock:
+            if not self._payloads_parts and not self._storage:
+                return None
+
+            payloads = self._payloads_parts[:]
+            self._payloads_parts.clear()
+
+        return Response(
+            make_id(),
+            _utc_now_iso_format(),
+            (payloads if payloads else None),
+            self._storage.copy()
+        )
+
 
     @abstractmethod
     def execute(self, req: RequestPayloadPart, storage: Optional[Storage]) -> ResponsePayloadPart:
